@@ -55,15 +55,15 @@ pub trait ToSVG {
 /// ```
 impl ToSVG for Drawing {
     fn to_svg(&self) -> Result<String, Box<dyn Error>> {
-        let offset = -self.canvas_size / 2.;
+        let offset = -self.canvas_size() / 2.;
         Ok(format!(
             r#"<svg viewBox="{offset_x} {offset_y} {max_x} {max_y}">{}</svg>"#,
             self.shapes().to_svg()?,
             // self.shapes()[0],
             offset_x = offset.x,
             offset_y = offset.y,
-            max_x = self.canvas_size.x,
-            max_y = self.canvas_size.y,
+            max_x = self.canvas_size().x,
+            max_y = self.canvas_size().y,
         ))
     }
 }
